@@ -1,14 +1,30 @@
-"""Functions which return a likeness score."""
-import logging
+"""Functions which return a likeness score.
+
+See Also:
+    The :class:`~rics.mapping.HeuristicScore` class.
+"""
 from typing import Iterable, Optional
 
 from rics.mapping.types import CandidateType, ContextType, ValueType
 
-LOGGER = logging.getLogger(__name__)
+VERBOSE: bool = False
+"""If ``True`` enable optional DEBUG-level log messages on each score function invocation.
+
+Notes:
+    Not all functions have verbose messages.
+"""
 
 
-def modified_hamming(name: str, candidates: Iterable[str], context: Optional[ContextType]) -> Iterable[float]:
-    """Compute hamming distance modified by length ratio, from the back.
+def modified_hamming(
+    name: str,
+    candidates: Iterable[str],
+    context: Optional[ContextType],
+    add_length_ratio_term: bool = True,
+) -> Iterable[float]:
+    """Compute hamming distance modified by length ratio, from the back. Score range is ``[0, 1]``.
+
+    Keyword Args:
+        add_length_ratio_term: If ``True``, score is divided by ``abs(len(name) - len(candidate))``.
 
     Examples:
         >>> from rics.mapping.score_functions import modified_hamming
@@ -22,7 +38,7 @@ def modified_hamming(name: str, candidates: Iterable[str], context: Optional[Con
         sz = min(len(candidate), len(name))
         same = sum([name[i] == candidate[i] for i in range(-sz, 0)])
 
-        ratio = 1 / (1 + abs(len(candidate) - len(name)))
+        ratio = (1 / (1 + abs(len(candidate) - len(name)))) if add_length_ratio_term else 1
         normalized_hamming = same / sz
 
         return ratio * normalized_hamming
